IntoIterator

Trait IntoIterator 

1.0.0 · Source
pub trait IntoIterator {
    type Item;
    type IntoIter: Iterator<Item = Self::Item>;

    // Required method
    fn into_iter(self) -> Self::IntoIter;
}
Conversion into an Iterator.

By implementing IntoIterator for a type, you define how it will be converted to an iterator. This is common for types which describe a collection of some kind.

One benefit of implementing IntoIterator is that your type will work with Rust’s for loop syntax.

See also: FromIterator.

Examples

Basic usage:

let v = [1, 2, 3];
let mut iter = v.into_iter();

assert_eq!(Some(1), iter.next());
assert_eq!(Some(2), iter.next());
assert_eq!(Some(3), iter.next());
assert_eq!(None, iter.next());

Implementing IntoIterator for your type:

// A sample collection, that's just a wrapper over Vec<T>
#[derive(Debug)]
struct MyCollection(Vec<i32>);

// Let's give it some methods so we can create one and add things
// to it.
impl MyCollection {
    fn new() -> MyCollection {
        MyCollection(Vec::new())
    }

    fn add(&mut self, elem: i32) {
        self.0.push(elem);
    }
}

// and we'll implement IntoIterator
impl IntoIterator for MyCollection {
    type Item = i32;
    type IntoIter = std::vec::IntoIter<Self::Item>;

    fn into_iter(self) -> Self::IntoIter {
        self.0.into_iter()
    }
}

// Now we can make a new collection...
let mut c = MyCollection::new();

// ... add some stuff to it ...
c.add(0);
c.add(1);
c.add(2);

// ... and then turn it into an Iterator:
for (i, n) in c.into_iter().enumerate() {
    assert_eq!(i as i32, n);
}

It is common to use IntoIterator as a trait bound. This allows the input collection type to change, so long as it is still an iterator. Additional bounds can be specified by restricting on Item:

fn collect_as_strings<T>(collection: T) -> Vec<String>
where
    T: IntoIterator,
    T::Item: std::fmt::Debug,
{
    collection
        .into_iter()
        .map(|item| format!("{item:?}"))
        .collect()
}

Required Associated Types

1.0.0 · Source

type Item

The type of the elements being iterated over.

1.0.0 · Source

type IntoIter: Iterator<Item = Self::Item>

Which kind of iterator are we turning this into?

Required Methods

1.0.0 · Source

fn into_iter(self) -> Self::IntoIter

Creates an iterator from a value.

See the module-level documentation for more.

Examples
let v = [1, 2, 3];
let mut iter = v.into_iter();

assert_eq!(Some(1), iter.next());
assert_eq!(Some(2), iter.next());
assert_eq!(Some(3), iter.next());
assert_eq!(None, iter.next());

Implementors

Source

impl IntoIterator for Fields

Source

impl IntoIterator for Error

Source

impl IntoIterator for Array

Source

impl IntoIterator for ArrayOfTables

Source

impl IntoIterator for InlineTable

Source

impl IntoIterator for Table

Source

impl IntoIterator for derive_deftly_macros::prelude::TokenStream

1.29.0 · Source

impl IntoIterator for proc_macro::TokenStream

Source

impl<'a> IntoIterator for &'a Fields

Source

impl<'a> IntoIterator for &'a Error

1.10.0 · Source

impl<'a> IntoIterator for &'a UnixListener

1.6.0 · Source

impl<'a> IntoIterator for &'a Path

1.6.0 · Source

impl<'a> IntoIterator for &'a PathBuf

Source

impl<'a> IntoIterator for &'a mut Fields

Source

type Item = &'a mut Field

Source

type IntoIter = IterMut<'a, Field>



impl<'a, I> IntoIterator for &'a IntoChunks<I>
where I: Iterator, <I as Iterator>::Item: 'a,



type Item = Chunk<'a, I>



type IntoIter = Chunks<'a, I>

1.80.0 · Source

impl<'a, I, A> IntoIterator for &'a Box<[I], A>
where A: Allocator,

1.80.0 · Source

impl<'a, I, A> IntoIterator for &'a mut Box<[I], A>
where A: Allocator,



impl<'a, K, I, F> IntoIterator for &'a ChunkBy<K, I, F>
where I: Iterator, <I as Iterator>::Item: 'a, F: FnMut(&<I as Iterator>::Item) -> K, K: PartialEq,



type Item = (K, Group<'a, K, I, F>)



type IntoIter = Groups<'a, K, I, F>

Source

impl<'a, K, V> IntoIterator for &'a indexmap::map::slice::Slice<K, V>

Source

type IntoIter = Iter<'a, K, V>

Source

type Item = (&'a K, &'a V)

Source

impl<'a, K, V> IntoIterator for &'a mut indexmap::map::slice::Slice<K, V>

1.0.0 · Source

impl<'a, K, V, A> IntoIterator for &'a BTreeMap<K, V, A>
where A: Allocator + Clone,

Source

type Item = (&'a K, &'a V)

Source

type IntoIter = Iter<'a, K, V>

1.0.0 · Source

impl<'a, K, V, A> IntoIterator for &'a mut BTreeMap<K, V, A>
where A: Allocator + Clone,

Source

impl<'a, K, V, S> IntoIterator for &'a IndexMap<K, V, S>

Source

type Item = (&'a K, &'a V)

Source

type IntoIter = Iter<'a, K, V>

1.0.0 · Source

impl<'a, K, V, S> IntoIterator for &'a std::collections::hash::map::HashMap<K, V, S>

Source

type Item = (&'a K, &'a V)

Source

type IntoIter = Iter<'a, K, V>

Source

impl<'a, K, V, S> IntoIterator for &'a mut IndexMap<K, V, S>

1.0.0 · Source

impl<'a, K, V, S> IntoIterator for &'a mut std::collections::hash::map::HashMap<K, V, S>

Source

impl<'a, K, V, S, A> IntoIterator for &'a hashbrown::map::HashMap<K, V, S, A>
where A: Allocator,

Source

type Item = (&'a K, &'a V)

Source

type IntoIter = Iter<'a, K, V>

Source

impl<'a, K, V, S, A> IntoIterator for &'a mut hashbrown::map::HashMap<K, V, S, A>
where A: Allocator,

1.4.0 · Source

impl<'a, T> IntoIterator for &'a Option<T>

1.0.0 · Source

impl<'a, T> IntoIterator for &'a [T]

Source

impl<'a, T> IntoIterator for &'a indexmap::set::slice::Slice<T>

Source

impl<'a, T> IntoIterator for &'a std::sync::mpmc::Receiver<T>

Source

type Item = T

Source

type IntoIter = Iter<'a, T>

1.1.0 · Source

impl<'a, T> IntoIterator for &'a std::sync::mpsc::Receiver<T>

Source

type Item = T

Source

type IntoIter = Iter<'a, T>

1.4.0 · Source

impl<'a, T> IntoIterator for &'a mut Option<T>

1.0.0 · Source

impl<'a, T> IntoIterator for &'a mut [T]

Source

impl<'a, T, A> IntoIterator for &'a HashTable<T, A>
where A: Allocator,

1.0.0 · Source

impl<'a, T, A> IntoIterator for &'a BTreeSet<T, A>
where A: Allocator + Clone,

1.0.0 · Source

impl<'a, T, A> IntoIterator for &'a VecDeque<T, A>
where A: Allocator,

1.0.0 · Source

impl<'a, T, A> IntoIterator for &'a BinaryHeap<T, A>
where A: Allocator,

1.0.0 · Source

impl<'a, T, A> IntoIterator for &'a LinkedList<T, A>
where A: Allocator,

1.0.0 · Source

impl<'a, T, A> IntoIterator for &'a Vec<T, A>
where A: Allocator,

Source

impl<'a, T, A> IntoIterator for &'a mut HashTable<T, A>
where A: Allocator,

1.0.0 · Source

impl<'a, T, A> IntoIterator for &'a mut VecDeque<T, A>
where A: Allocator,

1.0.0 · Source

impl<'a, T, A> IntoIterator for &'a mut LinkedList<T, A>
where A: Allocator,

1.0.0 · Source

impl<'a, T, A> IntoIterator for &'a mut Vec<T, A>
where A: Allocator,

1.4.0 · Source

impl<'a, T, E> IntoIterator for &'a Result<T, E>

1.4.0 · Source

impl<'a, T, E> IntoIterator for &'a mut Result<T, E>

Source

impl<'a, T, N> IntoIterator for &'a GenericArray<T, N>
where T: 'a, N: ArrayLength<T>,

Source

impl<'a, T, N> IntoIterator for &'a mut GenericArray<T, N>
where T: 'a, N: ArrayLength<T>,

Source

impl<'a, T, P> IntoIterator for &'a Punctuated<T, P>

Source

impl<'a, T, P> IntoIterator for &'a mut Punctuated<T, P>

Source

impl<'a, T, S> IntoIterator for &'a IndexSet<T, S>

1.0.0 · Source

impl<'a, T, S> IntoIterator for &'a derive_deftly_macros::prelude::HashSet<T, S>

Source

impl<'a, T, S, A> IntoIterator for &'a hashbrown::set::HashSet<T, S, A>
where A: Allocator,

1.0.0 · Source

impl<'a, T, const N: usize> IntoIterator for &'a [T; N]

1.0.0 · Source

impl<'a, T, const N: usize> IntoIterator for &'a mut [T; N]

Source

impl<'s> IntoIterator for &'s Array

Source

type Item = &'s Value

Source

type IntoIter = Box<dyn Iterator<Item = &'s Value> + 's>

Source

impl<'s> IntoIterator for &'s ArrayOfTables

Source

type Item = &'s Table

Source

type IntoIter = Box<dyn Iterator<Item = &'s Table> + 's>

Source

impl<'s> IntoIterator for &'s InlineTable

Source

type Item = (&'s str, &'s Value)

Source

type IntoIter = Box<dyn Iterator<Item = (&'s str, &'s Value)> + 's>

Source

impl<'s> IntoIterator for &'s Table

Source

type Item = (&'s str, &'s Item)

Source

type IntoIter = Box<dyn Iterator<Item = (&'s str, &'s Item)> + 's>

Source

impl<A> IntoIterator for Range<A>
where A: Step,

Source

impl<A> IntoIterator for RangeFrom<A>
where A: Step,

Source

impl<A> IntoIterator for RangeInclusive<A>
where A: Step,



impl<I> IntoIterator for &RcIter<I>
where I: Iterator,

Return an iterator from &RcIter<I> (by simply cloning it).



type Item = <I as Iterator>::Item



type IntoIter = RcIter<I>

1.0.0 · Source

impl<I> IntoIterator for I
where I: Iterator,

1.80.0 · Source

impl<I, A> IntoIterator for Box<[I], A>
where A: Allocator,

Source

impl<K, V> IntoIterator for Box<Slice<K, V>>

1.0.0 · Source

impl<K, V, A> IntoIterator for BTreeMap<K, V, A>
where A: Allocator + Clone,

Source

impl<K, V, S> IntoIterator for IndexMap<K, V, S>

1.0.0 · Source

impl<K, V, S> IntoIterator for std::collections::hash::map::HashMap<K, V, S>

Source

impl<K, V, S, A> IntoIterator for hashbrown::map::HashMap<K, V, S, A>
where A: Allocator,

1.0.0 · Source

impl<T> IntoIterator for Option<T>

Source

impl<T> IntoIterator for Box<Slice<T>>

Source

impl<T> IntoIterator for std::sync::mpmc::Receiver<T>

1.1.0 · Source

impl<T> IntoIterator for std::sync::mpsc::Receiver<T>

Source

impl<T, A> IntoIterator for HashTable<T, A>
where A: Allocator,

1.0.0 · Source

impl<T, A> IntoIterator for BTreeSet<T, A>
where A: Allocator + Clone,

1.0.0 · Source

impl<T, A> IntoIterator for VecDeque<T, A>
where A: Allocator,

1.0.0 · Source

impl<T, A> IntoIterator for BinaryHeap<T, A>
where A: Allocator,

1.0.0 · Source

impl<T, A> IntoIterator for LinkedList<T, A>
where A: Allocator,

1.0.0 · Source

impl<T, A> IntoIterator for Vec<T, A>
where A: Allocator,

1.0.0 · Source

impl<T, E> IntoIterator for Result<T, E>

Source

impl<T, N> IntoIterator for GenericArray<T, N>
where N: ArrayLength<T>,

Source

impl<T, P> IntoIterator for Punctuated<T, P>

Source

impl<T, S> IntoIterator for IndexSet<T, S>

1.0.0 · Source

impl<T, S> IntoIterator for derive_deftly_macros::prelude::HashSet<T, S>

Source

impl<T, S, A> IntoIterator for hashbrown::set::HashSet<T, S, A>
where A: Allocator,

1.53.0 · Source

impl<T, const N: usize> IntoIterator for [T; N]